import { 
  select, 
  geoPath, 
  geoNaturalEarth1,
  zoom, 
  event,
  scaleOrdinal,
  schemeSpectral
} from "d3";

import { loadAndProcessData } from "./loadAndProcessData";
import { colorLegend } from "./colorLegend";

const svg = select("svg");

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);



const g = svg.append("g");

const colorLegendG = svg.append("g")
		.attr("transform", `translate(50, 300)`);
    
g.append("path")
	.attr("class", "sphere")
	.attr("d", pathGenerator({type: "Sphere"}));

svg.call(zoom().on("zoom", () => {
	g.attr("transform", event.transform);
}));

const colorScale = scaleOrdinal();

const colorValue = d => d.properties.income_grp;

loadAndProcessData().then(countries => {

  colorScale
    .domain(countries.features.map(colorValue))
  	.domain(colorScale.domain().sort().reverse())
  	.range(schemeSpectral[colorScale.domain().length]);

  colorLegendG.call(colorLegend, {
      colorScale,
      circleRadius: 10,
  		spacing: 22,
  		textOffset: 30,
    	backgroundRectWidth:150
});
  
  g.selectAll("path").data(countries.features)	
  		.enter().append("path")
  			.attr("class", "country")
  			.attr("d", pathGenerator)
  			.attr("fill", d => colorScale(colorValue(d)))
  		.append("title")
  			.text(d => d.properties.name + ": " + colorValue(d));

});

// use d.name for name
// use d.iso_n3 for id

